﻿//     Copyright (c) Sitecore Corporation 1999-2015
/* jshint unused: vars */
require.config({
    paths: {
        CommerceBasePage: "/sitecore/shell/client/Applications/MerchandisingManager/CommerceBasePage"
    }
});

define(["sitecore", "CommerceBasePage"], function (Sitecore, cbp) {
    var Commerce_Static_Catalog_Set = cbp.extend({
        disableActions: false,
        initialized: function () {
            cbp.prototype.initialized.call(this);
            var self = this;

            this.HelpProvider.set("isReady", true);
            this.HelpProvider.refresh();

            var catalogSetId = CommerceUtilities.loadPageVar("target");
            this.set("targetId", catalogSetId);
            this.CatalogDataSource.on("change:items", this.bindModifiedCatalogCollection, this);

            //For Concurrency Saving
            this.set("lastModified", null);
            this.set("overrideChanges", false);

            if (catalogSetId) {
                var token = Sitecore.Helpers.antiForgery.getAntiForgeryToken();
                var ajaxToken = {};
                ajaxToken[token.headerKey] = token.value;

                $.ajax({
                    url: "/api/sitecore/CommerceSearch/GetItem",
                    type: "POST",
                    headers: ajaxToken,
                    context: this,
                    data: {
                        id: catalogSetId
                    },
                    success: function (data) {
                        self.HeaderTitle.set("text", data.DisplayName);
                        self.TitleControl.set("text", data.DisplayName);
                        self.set("itemPath", data.Path);

                        if (this.Name) {
                            this.Name.set("text", data.Name);
                            this.Name.set("isEnabled", false);
                        }

                        self.HeaderTitleLabel.set("text", self.ItemTypeDictionary.get("StaticCatalogSet"));

                        var catalogStringArray = data.IncludedCatalogs.split("|");
                        self.set("selectedCatalogs", catalogStringArray);

                        self.CatalogDataSource.set("isReady", true);
                        self.CatalogDataSource.refresh();

                        //For Concurrency Saving
                        self.set("lastModified", data.LastModified);
                    }
                });
            } else {
                self.HeaderTitle.set("text", self.ItemTypeDictionary.get("Create Static Catalog Group"));
                self.TitleControl.set("text", self.ItemTypeDictionary.get("Create Static Catalog Group"));

                this.set("templateId", CommerceUtilities.loadPageVar("template"));
                this.set("parentId", CommerceUtilities.loadPageVar("parent"));

                self.CatalogDataSource.set("isReady", true);
                self.CatalogDataSource.refresh();
            }
        },

        disableIfAX: function () {
            $(".cs-commerceitem :input").prop("disabled", true);
            this.StaticGroupActionControl.set("isVisible", false);

            $(".sc-CommerceDateTime :input").prop("disabled", true);
        },

        saveCatalogGroup: function () {
            var id = this.get("targetId");
            if (id) {
                this.updateCatalogGroup();
            } else {
                this.createCatalogGroup();
            }
        },

        updateCatalogGroup: function () {
            this.hideHeaderActionsMessage();
            var invalidFieldNames = [];
            if (!this.validateRequiredFields(invalidFieldNames)) {
                this.StaticGroupActionControl.get("actions")[0].isEnabled(false);
                this.showRequiredFieldsMessages(invalidFieldNames);
                return;
            }

            this.displayInProgressMessage();
            var baseFields = this.StaticCatalogSet.get("editFunctionBody");
            var dataObject = {};

            this.addRendererFieldsToObject(dataObject, baseFields);
            // Build and add catalog list. 
            var checkedCatalogs = this.Catalogs.get("checkedItemIds");
            var checkedCatalogString = "";
            for (i = 0; i < checkedCatalogs.length; i++) {
                if (checkedCatalogString !== "") {
                    checkedCatalogString += "|";
                }

                checkedCatalogString += checkedCatalogs[i];
            }

            var self = this;

            dataObject.itemId = this.get("targetId");
            dataObject.IncludedCatalogs = checkedCatalogString;

            //For Concurrency Saving
            dataObject.lastModified = this.get("lastModified");
            dataObject.overrideChanges = this.get("overrideChanges");

            var token = Sitecore.Helpers.antiForgery.getAntiForgeryToken();
            var ajaxToken = {};
            ajaxToken[token.headerKey] = token.value;

            $.ajax({
                url: "/api/sitecore/CommerceStaticCatalogGroup/Update",
                type: "POST",
                headers: ajaxToken,
                data: dataObject,
                context: this,
                success: function (data) {
                    if (data.Status == "failed") {
                        this.hideInProgressMessage();
                        var self = this;
                        this.StaticGroupActionControl.get("actions")[0].isEnabled(false);

                        //For Concurrency Saving
                        this.set("overrideChanges", false);

                        for (i = 0; i < data.Errors.length; i++) {
                            this.HeaderActionsMessageBar.addMessage("error", data.Errors[i].ErrorMessage);
                            $("[data-sc-id='" + data.Errors[i].ControlId + "']").addClass("sc-validation");
                        }
                        this.HeaderActionsMessageBar.set("isVisible", true);
                        $(".sc-validation").change(function () {
                            self.updateValidationError($(this));
                        });
                        $(".sc-validation.sc-datepicker").click(function () {
                            self.updateValidationError($(this));
                        });
                    } else if (data.Status == "priorUpdate") {
                        this.hideInProgressMessage();
                        //For Concurrency Saving
                        this.ConcurrencyAlert.show();
                    } else {
                        this.hideInProgressMessage(true);
                        this.setPageIsDirty(false);

                        //For Concurrency Saving
                        this.set("overrideChanges", false);
                        if (data.Status.indexOf("success") === 0) {
                            this.set("lastModified", data.Status.split('|')[1]);
                        }
                    }
                }
            });
        },

        //For Concurrency Saving
        cancelChanges: function () {
            window.location.reload();
            this.ConcurrencyAlert.hide();
        },

        //For Concurrency Saving
        overridePreviousChanges: function () {
            this.set("overrideChanges", true);
            this.updateCatalogGroup();
            this.ConcurrencyAlert.hide();
        },

        createCatalogGroup: function () {
            this.hideHeaderActionsMessage();
            var invalidFieldNames = [];
            if (!this.validateRequiredFields(invalidFieldNames)) {
                this.StaticGroupActionControl.get("actions")[0].isEnabled(false);
                this.showRequiredFieldsMessages(invalidFieldNames);
                return;
            }

            var baseFields = this.StaticCatalogSet.get("editFunctionBody");
            var dataObject = {};

            this.addRendererFieldsToObject(dataObject, baseFields);
            // Build and add catalog list. 
            var checkedCatalogs = this.Catalogs.get("checkedItemIds");
            var checkedCatalogString = "";
            for (i = 0; i < checkedCatalogs.length; i++) {
                if (checkedCatalogString !== "") {
                    checkedCatalogString += "|";
                }

                checkedCatalogString += checkedCatalogs[i];
            }

            var self = this;
            dataObject.IncludedCatalogs = checkedCatalogString;
            dataObject.templateId = this.get("templateId");
            dataObject.parentId = this.get("parentId");

            dataObject.name = this.Name.get("text") !== null ? this.Name.get("text").trim() : "";

            var token = Sitecore.Helpers.antiForgery.getAntiForgeryToken();
            var ajaxToken = {};
            ajaxToken[token.headerKey] = token.value;

            $.ajax({
                url: "/api/sitecore/CommerceStaticCatalogGroup/Create",
                type: "POST",
                headers: ajaxToken,
                data: dataObject,
                context: this,
                success: function (data) {
                    this.HeaderActionsMessageBar.removeMessages();
                    if (data.Status == "failed") {
                        this.hideInProgressMessage();
                        for (var i = 0; i < data.Errors.length; i++) {
                            this.HeaderActionsMessageBar.addMessage("error", data.Errors[i].ErrorMessage);
                            $("[data-sc-id='" + data.Errors[i].ControlId + "']").addClass("sc-validation");
                        }
                        this.ErrorsMessageBar.set("isVisible", true);
                        $(".sc-validation").change(function () {
                            self.updateValidationError($(this));
                        });
                        $(".sc-validation.sc-datepicker").click(function () {
                            self.updateValidationError($(this));
                        });
                    } else {
                        this.hideInProgressMessageCreate(true, "Catalog Group Created");
                        this.setPageIsDirty(false);
                        this.set("newTargetId", data);                       
                        setTimeout($.proxy(this.redirectToSavedCatalogGroup, this), 10000);
                    }
                }
            });

        },

        redirectToSavedCatalogGroup: function () {
            window.location.assign('/sitecore/client/Applications/MerchandisingManager/Commerce Static Catalog Group?target=' + this.get("newTargetId"));
        },

        updateValidationError: function (obj) {
            obj.removeClass("sc-validation");
            if ($(".sc-validation").length === 0) {
                this.StaticGroupActionControl.get("actions")[0].isEnabled(true);
                this.hideHeaderActionsMessage();
            }
        },

        bindModifiedCatalogCollection: function () {
            var catalogs = this.CatalogDataSource.get("items");
            for (i = 0; i < catalogs.length; i++) {
                var currentItem = catalogs[i];
                currentItem.itemId = currentItem.catalogName;
            }

            this.Catalogs.set("items", catalogs);

            var catalogStringArray = this.get("selectedCatalogs");
            if (catalogStringArray) {
                var complexCatalogArray = [];
                for (var i = 0; i < catalogStringArray.length; i++) {
                    complexCatalogArray.push(catalogStringArray[i]);
                }

                this.Catalogs.viewModel.checkItems(complexCatalogArray);
            }
        },

        updateSaveButton: function (status) {
            this.StaticGroupActionControl.get("actions")[0].isEnabled(status);
        }
    });

    return Commerce_Static_Catalog_Set;
});