﻿//     Copyright (c) Sitecore Corporation 1999-2015
/* jshint unused: vars */
require.config({
    paths: {
        CommerceBasePage: "/sitecore/shell/client/Applications/MerchandisingManager/CommerceBasePage"
    }
});

define(["sitecore", "CommerceBasePage", "jquery"], function (Sitecore, cbp, $) {

    var productTabId = "{DFD09B88-76D8-4AC0-BA38-F1E886773175}";
    var categoryTabId = "{44FFA625-531A-459C-91B3-8C07005DF56F}";
    var catalogTabId = "{524233A7-3A33-47BF-908E-15229F8AC89F}";
    var customCatalogTabId = "{12803625-D46D-4811-8CD3-867DF2715D2E}";

    var queryCount = 0;
    var tabCount = 4;
    var shouldShowOrHideTabs = false;

    var Search = cbp.extend({
        initialized: function () {
            cbp.prototype.initialized.call(this);
            this.HelpProvider.set("isReady", true);
            this.HelpProvider.refresh();

            this.SearchBox.on("change", this.search, this);
            this.handleBrowserHistoryChange();
            var searchTerm = this.getSearchTermFromUrl();
            this.SearchBox.set("text", searchTerm);
            this.setHeaderTitle(searchTerm);
            this.set("selectedTab", null);
            this.SearchTabs.on("change:selectedTab", this.selectedTabChanged, this);

            // Initialize visibility for lists and facets
            this.CatalogList.set("isVisible", false);
            this.CustomCatalogList.set("isVisible", false);
            this.CategoryList.set("isVisible", false);
            this.ProductList.set("isVisible", true);

            this.CatalogFacets.set("isVisible", false);
            this.CustomCatalogFacets.set("isVisible", false);
            this.CategoryFacets.set("isVisible", false);
            this.ProductFacets.set("isVisible", true);

            // Set-up tab visibility-change handlers
            var self = this;

            this.ProductDataSource.setCompletedQueryCallback($.proxy(self.showOrHideProductsTab, self));
            this.CategoryDataSource.setCompletedQueryCallback($.proxy(self.showOrHideCategoriesTab, self));
            this.CatalogDataSource.setCompletedQueryCallback($.proxy(self.showOrHideCatalogsTab, self));
            this.CustomCatalogDataSource.setCompletedQueryCallback($.proxy(self.showOrHideCustomCatalogsTab, self));

            // Initial query for data sources
            this.refreshDataSources();

            // Set up result counts in tabs
            this.addSpansToTabs();
            this.CatalogDataSource.on("change:totalItemCount", this.catalogCountChanged, this);
            this.CustomCatalogDataSource.on("change:totalItemCount", this.customCatalogCountChanged, this);
            this.CategoryDataSource.on("change:totalItemCount", this.categoryCountChanged, this);
            this.ProductDataSource.on("change:totalItemCount", this.productCountChanged, this);

            this.FilterPanel.viewModel.$el.addClass("sc-CommercePanel");

            // Set up scroll listeners.
            $(window).on("scroll", $.proxy(self.infiniteScrollCatalogs, self));
            $(window).on("scroll", $.proxy(self.infiniteScrollCategories, self));
            $(window).on("scroll", $.proxy(self.infiniteScrollProducts, self));
            $(window).on("scroll", $.proxy(self.infiniteScrollCustomCatalogs, self));
        },

        addSpansToTabs: function () {
            $("li[data-tab-id=\\{DFD09B88-76D8-4AC0-BA38-F1E886773175\\}] > a").append("<span class='badge'></span>"); // Products
            $("li[data-tab-id=\\{44FFA625-531A-459C-91B3-8C07005DF56F\\}] > a").append("<span class='badge'></span>"); // Categories 
            $("li[data-tab-id=\\{524233A7-3A33-47BF-908E-15229F8AC89F\\}] > a").append("<span class='badge'></span>"); // Catalog
            $("li[data-tab-id=\\{12803625-D46D-4811-8CD3-867DF2715D2E\\}] > a").append("<span class='badge'></span>"); // Custom Catalog
        },

        catalogCountChanged: function () {
            var count = this.CatalogDataSource.get("totalItemCount") > 99 ? "99+" : this.CatalogDataSource.get("totalItemCount");
            $("li[data-tab-id=\\{524233A7-3A33-47BF-908E-15229F8AC89F\\}] > a > span").html(count);
        },

        customCatalogCountChanged: function () {
            var count = this.CustomCatalogDataSource.get("totalItemCount") > 99 ? "99+" : this.CustomCatalogDataSource.get("totalItemCount");
            $("li[data-tab-id=\\{12803625-D46D-4811-8CD3-867DF2715D2E\\}] > a > span").html(count);
        },

        categoryCountChanged: function () {
            var count = this.CategoryDataSource.get("totalItemCount") > 99 ? "99+" : this.CategoryDataSource.get("totalItemCount");
            $("li[data-tab-id=\\{44FFA625-531A-459C-91B3-8C07005DF56F\\}] > a > span").html(count);
        },

        productCountChanged: function () {
            var count = this.ProductDataSource.get("totalItemCount") > 99 ? "99+" : this.ProductDataSource.get("totalItemCount");
            $("li[data-tab-id=\\{DFD09B88-76D8-4AC0-BA38-F1E886773175\\}] > a > span").html(count);
        },

        setHeaderTitle: function (searchTerm) {

            var youSearchedForFormat = this.StringResourcesDictionary.get("YouSearchedFor");
            var youSearchedForText = Sitecore.Helpers.string.format(youSearchedForFormat, searchTerm);
            this.HeaderTitle.set("text", youSearchedForText);
            this.TitleControl.set("text", youSearchedForText);
        },

        selectedTabChanged: function () {

            var selectedTabId = this.SearchTabs.get("selectedTab");
            this.set("selectedTab", selectedTabId);

            if (selectedTabId == productTabId) {

                this.CatalogList.set("isVisible", false);
                this.CustomCatalogList.set("isVisible", false);
                this.CategoryList.set("isVisible", false);
                this.ProductList.set("isVisible", true);

                this.CatalogFacets.set("isVisible", false);
                this.CustomCatalogFacets.set("isVisible", false);
                this.CategoryFacets.set("isVisible", false);
                this.ProductFacets.set("isVisible", true);

            } else if (selectedTabId == categoryTabId) {

                this.CatalogList.set("isVisible", false);
                this.CustomCatalogList.set("isVisible", false);
                this.CategoryList.set("isVisible", true);
                this.ProductList.set("isVisible", false);

                this.CatalogFacets.set("isVisible", false);
                this.CustomCatalogFacets.set("isVisible", false);
                this.CategoryFacets.set("isVisible", true);
                this.ProductFacets.set("isVisible", false);

            } else if (selectedTabId == catalogTabId) {

                this.CatalogList.set("isVisible", true);
                this.CustomCatalogList.set("isVisible", false);
                this.CategoryList.set("isVisible", false);
                this.ProductList.set("isVisible", false);

                this.CatalogFacets.set("isVisible", true);
                this.CustomCatalogFacets.set("isVisible", false);
                this.CategoryFacets.set("isVisible", false);
                this.ProductFacets.set("isVisible", false);

            } else if (selectedTabId == customCatalogTabId) {

                this.CatalogList.set("isVisible", false);
                this.CustomCatalogList.set("isVisible", true);
                this.CategoryList.set("isVisible", false);
                this.ProductList.set("isVisible", false);

                this.CatalogFacets.set("isVisible", false);
                this.CustomCatalogFacets.set("isVisible", true);
                this.CategoryFacets.set("isVisible", false);
                this.ProductFacets.set("isVisible", false);
            }
        },

        refreshDataSources: function () {

            queryCount = 0;
            shouldShowOrHideTabs = true;

            var searchTerm = this.getSearchTermFromUrl();

            this.setHeaderTitle(searchTerm);
            this.SearchBox.set("text", searchTerm);

            this.CatalogDataSource.set("dataUrl", "/api/sitecore/CommerceSearch/GetContentSearchResultsForItemType");
            this.CatalogDataSource.set("commerceItemType", "Catalog");
            this.CatalogDataSource.set("isReady", true);
            this.CatalogDataSource.set("searchTerm", searchTerm);

            this.CustomCatalogDataSource.set("dataUrl", "/api/sitecore/CommerceSearch/GetContentSearchResultsForItemType");
            this.CustomCatalogDataSource.set("commerceItemType", "VirtualCatalog");
            this.CustomCatalogDataSource.set("isReady", true);
            this.CustomCatalogDataSource.set("searchTerm", searchTerm);

            this.CategoryDataSource.set("dataUrl", "/api/sitecore/CommerceSearch/GetContentSearchResultsForItemType");
            this.CategoryDataSource.set("commerceItemType", "Category");
            this.CategoryDataSource.set("isReady", true);
            this.CategoryDataSource.set("searchTerm", searchTerm);

            this.ProductDataSource.set("dataUrl", "/api/sitecore/CommerceSearch/GetContentSearchResultsForItemType");
            this.ProductDataSource.set("commerceItemType", "Product");
            this.ProductDataSource.set("isReady", true);
            this.ProductDataSource.set("searchTerm", searchTerm);
        },

        getSearchTermFromUrl: function () {
            var hashString = window.location.hash;
            if (hashString && hashString.length > 0) {
                return window.location.hash.substring(1);
            }

            return null;
        },

        setSearchTermInUrl: function (searchTerm) {
            window.location.hash = '#' + searchTerm;
        },

        search: function () {
            var searchText = this.SearchBox.get("text");

            if (searchText) {
                searchText = searchText.trim();

                if (searchText) {
                    this.setSearchTermInUrl(searchText);
                }
            }
        },

        handleBrowserHistoryChange: function () {
            var self = this;
            $(document).ready(function () {
                if (window.history && window.history.pushState) {
                    $(window).on('hashchange', function (e) {
                        self.refreshDataSources();
                    });
                }
            });
        },



        showOrHideProductsTab: function () {
            var haveProducts = this.ProductDataSource.get("hasItems");
            var productsTab = $("li[data-tab-id='{DFD09B88-76D8-4AC0-BA38-F1E886773175}']");

            if (productsTab && haveProducts === true) {
                productsTab.show();
            } else {
                productsTab.hide();
            }

            queryCount++;

            if (queryCount >= tabCount && shouldShowOrHideTabs === true) {
                this.setSelectedTab();
            }
        },

        showOrHideCategoriesTab: function () {
            var haveCategories = this.CategoryDataSource.get("hasItems");
            var categoriesTab = $("li[data-tab-id='{44FFA625-531A-459C-91B3-8C07005DF56F}']");

            if (categoriesTab && haveCategories === true) {
                categoriesTab.show();
            } else {
                categoriesTab.hide();
            }

            queryCount++;

            if (queryCount >= tabCount && shouldShowOrHideTabs === true) {
                this.setSelectedTab();
            }
        },

        showOrHideCatalogsTab: function () {
            var haveCatalogs = this.CatalogDataSource.get("hasItems");
            var catalogsTab = $("li[data-tab-id='{524233A7-3A33-47BF-908E-15229F8AC89F}']");

            if (catalogsTab && haveCatalogs === true) {
                catalogsTab.show();
            } else {
                catalogsTab.hide();
            }

            queryCount++;

            if (queryCount >= tabCount && shouldShowOrHideTabs === true) {
                this.setSelectedTab();
            }
        },

        showOrHideCustomCatalogsTab: function () {
            var haveCustomCatalogs = this.CustomCatalogDataSource.get("hasItems");
            var customCatalogsTab = $("li[data-tab-id='{12803625-D46D-4811-8CD3-867DF2715D2E}']");

            if (customCatalogsTab && haveCustomCatalogs === true) {
                customCatalogsTab.show();
            } else {
                customCatalogsTab.hide();
            }

            queryCount++;

            if (queryCount >= tabCount && shouldShowOrHideTabs === true) {
                this.setSelectedTab();
            }
        },

        setSelectedTab: function () {
            var haveProducts = this.ProductDataSource.get("hasItems");
            var haveCategories = this.CategoryDataSource.get("hasItems");
            var haveCatalogs = this.CatalogDataSource.get("hasItems");
            var haveCustomCatalogs = this.CustomCatalogDataSource.get("hasItems");

            if (haveProducts) {
                this.SearchTabs.set("isVisible", true);
                this.SearchTabs.set("selectedTab", productTabId);
                this.selectedTabChanged();
                this.NoSearchResultsText.set("isVisible", false);
            } else if (haveCategories) {
                this.SearchTabs.set("isVisible", true);
                this.SearchTabs.set("selectedTab", categoryTabId);
                this.selectedTabChanged();
                this.NoSearchResultsText.set("isVisible", false);
            } else if (haveCatalogs) {
                this.SearchTabs.set("isVisible", true);
                this.SearchTabs.set("selectedTab", catalogTabId);
                this.selectedTabChanged();
                this.NoSearchResultsText.set("isVisible", false);
            } else if (haveCustomCatalogs) {
                this.SearchTabs.set("isVisible", true);
                this.SearchTabs.set("selectedTab", customCatalogTabId);
                this.selectedTabChanged();
                this.NoSearchResultsText.set("isVisible", false);
            } else {
                this.CatalogList.set("isVisible", false);
                this.CustomCatalogList.set("isVisible", false);
                this.CategoryList.set("isVisible", false);
                this.ProductList.set("isVisible", false);
                this.SearchTabs.set("isVisible", false);
                this.NoSearchResultsText.set("isVisible", true);
            }

            shouldShowOrHideTabs = false;
        },

        isProductsTabSelected: function () {
            return this.SearchTabs.get("selectedTab") == "{DFD09B88-76D8-4AC0-BA38-F1E886773175}";
        },

        isCategoriesTabSelected: function () {
            return this.SearchTabs.get("selectedTab") == "{44FFA625-531A-459C-91B3-8C07005DF56F}";
        },

        isCatalogsTabSelected: function () {
            return this.SearchTabs.get("selectedTab") == "{524233A7-3A33-47BF-908E-15229F8AC89F}";
        },

        isCustomCatalogsTabSelected: function () {
            return this.SearchTabs.get("selectedTab") == customCatalogTabId;
        },

        infiniteScrollProducts: function () {
            var isBusy = this.ProductDataSource.get("isBusy");
            var hasMoreItems = this.ProductDataSource.get("hasMoreItems");

            if (this.isProductsTabSelected() && !isBusy && hasMoreItems) {
                var val = parseInt($(window).scrollTop(), 10) + parseInt($(window).height(), 10);
                if (val >= document.body.offsetHeight * 0.75) {
                    this.ProductDataSource.next();
                }
            }
        },

        infiniteScrollCategories: function () {
            var isBusy = this.CategoryDataSource.get("isBusy");
            var hasMoreItems = this.CategoryDataSource.get("hasMoreItems");

            if (this.isCategoriesTabSelected() && !isBusy && hasMoreItems) {
                var val = parseInt($(window).scrollTop(), 10) + parseInt($(window).height(), 10);
                if (val >= document.body.offsetHeight * 0.75) {
                    this.CategoryDataSource.next();
                }
            }
        },

        infiniteScrollCatalogs: function () {
            var isBusy = this.CatalogDataSource.get("isBusy");
            var hasMoreItems = this.CatalogDataSource.get("hasMoreItems");

            if (this.isCatalogsTabSelected() && !isBusy && hasMoreItems) {
                var val = parseInt($(window).scrollTop(), 10) + parseInt($(window).height(), 10);
                if (val >= document.body.offsetHeight * 0.75) {
                    this.CatalogDataSource.next();
                }
            }
        },

        infiniteScrollCustomCatalogs: function () {
            var isBusy = this.CustomCatalogDataSource.get("isBusy");
            var hasMoreItems = this.CustomCatalogDataSource.get("hasMoreItems");

            if (this.isCustomCatalogsTabSelected() && !isBusy && hasMoreItems) {
                var val = parseInt($(window).scrollTop(), 10) + parseInt($(window).height(), 10);
                if (val >= document.body.offsetHeight * 0.75) {
                    this.CustomCatalogDataSource.next();
                }
            }
        }
    });

    return Search;
});